{pkgs, ...}: {
  home.packages = with pkgs; [
    # devenv
    unstable.devenv
    # Javascript
    nodejs
    nodePackages.yarn
    unstable.nodePackages.pnpm
    deno
    unstable.bun
    # PHP
    php
    # Python
    python3
    # Kubernetes
    azure-cli
    kubectl
    kubernetes-helm
    # Nix
    nil
    alejandra
    # Rust
    (rust-bin.stable.latest.default.override {
      extensions = ["rust-src" "llvm-tools-preview"];
    })
    pkg-config
    openssl
  ];

  programs.zsh.initExtra = ''
    export PATH=~/.npm-packages/bin:$PATH
    export NODE_PATH=~/.npm-packages/lib/node_modules
  '';

  programs.direnv = {
    enable = true;
    package = pkgs.unstable.direnv;
    config = {
      global.hide_env_diff = true;
    };
  };

  programs.java = {
    enable = true;
    package = pkgs.jdk21;
  };

  programs.zoxide = {
    enable = true;
  };

  # Bun Git config
  programs.git = {
    attributes = [
      "*.lockb binary diff=lockb"
    ];
    extraConfig = {
      diff.lockb.textconv = "bun";
      diff.lockb.binary = "true";
    };
  };
}
